# flowhunt
FlowHunt API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 3.14.5
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/flowhunt-python-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/flowhunt-python-sdk.git`)

Then import the package:
```python
import flowhunt
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import flowhunt
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import flowhunt
from flowhunt.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = flowhunt.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = flowhunt.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with flowhunt.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = flowhunt.ApiKeysApi(api_client)
    workspace_id = 'workspace_id_example' # str | 
    api_key_create_request = flowhunt.ApiKeyCreateRequest() # ApiKeyCreateRequest | 

    try:
        # Create Api Key
        api_response = api_instance.create_api_key(workspace_id, api_key_create_request)
        print("The response of ApiKeysApi->create_api_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApiKeysApi->create_api_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiKeysApi* | [**create_api_key**](docs/ApiKeysApi.md#create_api_key) | **POST** /v2/api_keys/create | Create Api Key
*ApiKeysApi* | [**delete_api_key**](docs/ApiKeysApi.md#delete_api_key) | **DELETE** /v2/api_keys/{api_key_id} | Delete Api Key
*ApiKeysApi* | [**search_api_key**](docs/ApiKeysApi.md#search_api_key) | **POST** /v2/api_keys/search | Search Api Key
*ApiKeysApi* | [**update_api_key**](docs/ApiKeysApi.md#update_api_key) | **PUT** /v2/api_keys/{api_key_id} | Update Api Key
*BillingApi* | [**add_addon_to_subscription**](docs/BillingApi.md#add_addon_to_subscription) | **POST** /v2/billing/addons/{product_id}/add | Add Addon To Subscription
*BillingApi* | [**create_change_plan_portal**](docs/BillingApi.md#create_change_plan_portal) | **POST** /v2/billing/portal/change-plan/create | Create Change Plan Portal
*BillingApi* | [**create_checkout**](docs/BillingApi.md#create_checkout) | **POST** /v2/billing/checkout/create | Create Checkout
*BillingApi* | [**create_update_info_portal**](docs/BillingApi.md#create_update_info_portal) | **POST** /v2/billing/portal/update-info/create | Create Update Info Portal
*BillingApi* | [**get_pricing_plans**](docs/BillingApi.md#get_pricing_plans) | **GET** /v2/billing/plans | Get Pricing Plans
*BillingApi* | [**get_user_plan**](docs/BillingApi.md#get_user_plan) | **GET** /v2/billing/plans/me | Get User Plan
*BillingApi* | [**stripe_webhook**](docs/BillingApi.md#stripe_webhook) | **POST** /v2/billing/webhook | Stripe Webhook
*ChatbotsApi* | [**create_chatbot**](docs/ChatbotsApi.md#create_chatbot) | **POST** /v2/chatbots/create | Create Chatbot
*ChatbotsApi* | [**delete_chatbot**](docs/ChatbotsApi.md#delete_chatbot) | **DELETE** /v2/chatbots/{chatbot_id} | Delete Chatbot
*ChatbotsApi* | [**get_chatbot**](docs/ChatbotsApi.md#get_chatbot) | **GET** /v2/chatbots/{chatbot_id} | Get Chatbot
*ChatbotsApi* | [**search_chatbots**](docs/ChatbotsApi.md#search_chatbots) | **POST** /v2/chatbots/ | Search Chatbots
*ChatbotsApi* | [**update_chatbot**](docs/ChatbotsApi.md#update_chatbot) | **PUT** /v2/chatbots/{chatbot_id} | Update Chatbot
*CreditsApi* | [**get_credit_balance**](docs/CreditsApi.md#get_credit_balance) | **GET** /v2/credits/balance | Get Credit Balance
*CreditsApi* | [**get_workspace_credit_balance**](docs/CreditsApi.md#get_workspace_credit_balance) | **GET** /v2/credits/workspace_balance | Get Workspace Credit Balance
*CreditsApi* | [**search_credit_transactions**](docs/CreditsApi.md#search_credit_transactions) | **POST** /v2/credits/search | Search Credit Transactions
*CreditsApi* | [**search_daily_credit_transactions**](docs/CreditsApi.md#search_daily_credit_transactions) | **POST** /v2/credits/search_daily | Search Daily Credit Transactions
*DocumentsApi* | [**create_document_category**](docs/DocumentsApi.md#create_document_category) | **POST** /v2/documents/categories/create | Create Document Category
*DocumentsApi* | [**create_faq**](docs/DocumentsApi.md#create_faq) | **POST** /v2/documents/faqs/create | Create Faq
*DocumentsApi* | [**delete_document**](docs/DocumentsApi.md#delete_document) | **DELETE** /v2/documents/{doc_id} | Delete Document
*DocumentsApi* | [**delete_document_category**](docs/DocumentsApi.md#delete_document_category) | **DELETE** /v2/documents/categories/{cat_id} | Delete Document Category
*DocumentsApi* | [**delete_faq**](docs/DocumentsApi.md#delete_faq) | **DELETE** /v2/documents/faqs/{faq_id} | Delete Faq
*DocumentsApi* | [**download_binary_document**](docs/DocumentsApi.md#download_binary_document) | **GET** /v2/documents/download/binary/{doc_id} | Download Binary Document
*DocumentsApi* | [**download_text_document**](docs/DocumentsApi.md#download_text_document) | **GET** /v2/documents/download/text/{doc_id} | Download Text Document
*DocumentsApi* | [**import_faq**](docs/DocumentsApi.md#import_faq) | **POST** /v2/documents/faqs/import | Import Faq
*DocumentsApi* | [**search_document_categories**](docs/DocumentsApi.md#search_document_categories) | **POST** /v2/documents/categories/search | Search Document Categories
*DocumentsApi* | [**search_documents**](docs/DocumentsApi.md#search_documents) | **POST** /v2/documents/search | Search Documents
*DocumentsApi* | [**search_faqs**](docs/DocumentsApi.md#search_faqs) | **POST** /v2/documents/faqs/search | Search Faqs
*DocumentsApi* | [**update_document**](docs/DocumentsApi.md#update_document) | **PUT** /v2/documents/{doc_id} | Update Document
*DocumentsApi* | [**update_document_category**](docs/DocumentsApi.md#update_document_category) | **PUT** /v2/documents/categories/{cat_id} | Update Document Category
*DocumentsApi* | [**update_faq**](docs/DocumentsApi.md#update_faq) | **PUT** /v2/documents/faqs/{faq_id} | Update Faq
*DocumentsApi* | [**upload_document**](docs/DocumentsApi.md#upload_document) | **POST** /v2/documents/upload/{cat_id} | Upload Document
*DocumentsApi* | [**upload_from_url_document**](docs/DocumentsApi.md#upload_from_url_document) | **POST** /v2/documents/upload-from-url/{cat_id} | Upload From Url Document
*FineTuningsApi* | [**create_image_ft**](docs/FineTuningsApi.md#create_image_ft) | **POST** /v2/photo_ai/images/ | Create Image Ft
*FineTuningsApi* | [**delete_file_ft**](docs/FineTuningsApi.md#delete_file_ft) | **DELETE** /v2/photo_ai/files/{file_key} | Delete File Ft
*FineTuningsApi* | [**delete_image_ft**](docs/FineTuningsApi.md#delete_image_ft) | **DELETE** /v2/photo_ai/images/{ft_id} | Delete Image Ft
*FineTuningsApi* | [**generate_image_prompt**](docs/FineTuningsApi.md#generate_image_prompt) | **POST** /v2/photo_ai/inference/images/generate-prompt | Generate Image Prompt
*FineTuningsApi* | [**generate_images**](docs/FineTuningsApi.md#generate_images) | **POST** /v2/photo_ai/inference/images | Generate Images
*FineTuningsApi* | [**get_file_ft**](docs/FineTuningsApi.md#get_file_ft) | **GET** /v2/photo_ai/files/{file_key} | Get File Ft
*FineTuningsApi* | [**get_inference_results**](docs/FineTuningsApi.md#get_inference_results) | **GET** /v2/photo_ai/inference/results/{inference_id} | Get Inference Results
*FineTuningsApi* | [**handle_replicate_webhook**](docs/FineTuningsApi.md#handle_replicate_webhook) | **POST** /v2/photo_ai/webhooks/replicate | Handle Replicate Webhook
*FineTuningsApi* | [**search_image_fts**](docs/FineTuningsApi.md#search_image_fts) | **POST** /v2/photo_ai/images/search | Search Image Fts
*FineTuningsApi* | [**search_inference_history**](docs/FineTuningsApi.md#search_inference_history) | **POST** /v2/photo_ai/inference/history | Search Inference History
*FineTuningsApi* | [**update_image_ft**](docs/FineTuningsApi.md#update_image_ft) | **PUT** /v2/photo_ai/images/{ft_id} | Update Image Ft
*FineTuningsApi* | [**upload_image_ft**](docs/FineTuningsApi.md#upload_image_ft) | **POST** /v2/photo_ai/files/{ft_type}/upload | Upload Image Ft
*FlowAssistantApi* | [**apply_flow_assistant_changes**](docs/FlowAssistantApi.md#apply_flow_assistant_changes) | **POST** /v2/flow_assistants/apply_changes | Apply Flow Assistant Changes
*FlowAssistantApi* | [**create_flow_assistant_session**](docs/FlowAssistantApi.md#create_flow_assistant_session) | **POST** /v2/flow_assistants/create | Create Flow Assistant Session
*FlowAssistantApi* | [**invoke_flow_assistant_response**](docs/FlowAssistantApi.md#invoke_flow_assistant_response) | **POST** /v2/flow_assistants/{session_id}/invoke | Invoke Flow Assistant Response
*FlowAssistantApi* | [**poll_flow_assistant_response**](docs/FlowAssistantApi.md#poll_flow_assistant_response) | **POST** /v2/flow_assistants/{session_id}/invocation_response/{from_timestamp} | Poll Flow Assistant Response
*FlowAssistantApi* | [**reject_flow_assistant_changes**](docs/FlowAssistantApi.md#reject_flow_assistant_changes) | **POST** /v2/flow_assistants/reject_changes | Reject Flow Assistant Changes
*FlowMessagesApi* | [**search_flow_messages**](docs/FlowMessagesApi.md#search_flow_messages) | **POST** /v2/chatbots/search/{session_id} | Search Flow Messages
*FlowSessionsApi* | [**delete_chatbot_session_view**](docs/FlowSessionsApi.md#delete_chatbot_session_view) | **DELETE** /v2/chatbots/sessions/{session_id} | Delete Chatbot Session View
*FlowSessionsApi* | [**get_chatbot_session_view**](docs/FlowSessionsApi.md#get_chatbot_session_view) | **GET** /v2/chatbots/sessions/{session_id} | Get Chatbot Session View
*FlowSessionsApi* | [**search_chatbot_sessions_view**](docs/FlowSessionsApi.md#search_chatbot_sessions_view) | **POST** /v2/chatbots/sessions/search | Search Chatbot Sessions View
*FlowSessionsApi* | [**update_chatbot_session_view**](docs/FlowSessionsApi.md#update_chatbot_session_view) | **PUT** /v2/chatbots/sessions/{session_id} | Update Chatbot Session View
*FlowWebhooksApi* | [**execute_third_party_webhook**](docs/FlowWebhooksApi.md#execute_third_party_webhook) | **POST** /v2/flows/webhooks/third_party_integrations/{trigger_type} | Execute Third Party Webhook
*FlowWebhooksApi* | [**execute_webhook**](docs/FlowWebhooksApi.md#execute_webhook) | **POST** /v2/flows/webhooks/{chatbot_id} | Execute Webhook
*FlowWebhooksApi* | [**execute_webhook_from_flow**](docs/FlowWebhooksApi.md#execute_webhook_from_flow) | **POST** /v2/flows/webhooks/from_flow/{flow_id} | Execute Webhook From Flow
*FlowsApi* | [**create_chatbot_session**](docs/FlowsApi.md#create_chatbot_session) | **POST** /v2/flows/sessions/create | Create Chatbot Session
*FlowsApi* | [**create_flow**](docs/FlowsApi.md#create_flow) | **POST** /v2/flows/create | Create Flow
*FlowsApi* | [**create_flow_category**](docs/FlowsApi.md#create_flow_category) | **POST** /v2/flows/categories/create | Create Flow Category
*FlowsApi* | [**create_flow_cron**](docs/FlowsApi.md#create_flow_cron) | **POST** /v2/flows/crons/create | Create Flow Cron
*FlowsApi* | [**create_flow_session**](docs/FlowsApi.md#create_flow_session) | **POST** /v2/flows/sessions/from_flow/create | Create Flow Session
*FlowsApi* | [**delete_attachment**](docs/FlowsApi.md#delete_attachment) | **DELETE** /v2/flows/sessions/{session_id}/attachments/{file_id} | Delete Attachment
*FlowsApi* | [**delete_flow**](docs/FlowsApi.md#delete_flow) | **DELETE** /v2/flows/{flow_id} | Delete Flow
*FlowsApi* | [**delete_flow_category**](docs/FlowsApi.md#delete_flow_category) | **DELETE** /v2/flows/categories/{cat_id} | Delete Flow Category
*FlowsApi* | [**delete_flow_cron**](docs/FlowsApi.md#delete_flow_cron) | **DELETE** /v2/flows/crons/{flow_id}/{cron_id} | Delete Flow Cron
*FlowsApi* | [**execute_flow_cron**](docs/FlowsApi.md#execute_flow_cron) | **POST** /v2/flows/crons/{flow_id}/{cron_id}/execute | Execute Flow Cron
*FlowsApi* | [**generate_commit_message**](docs/FlowsApi.md#generate_commit_message) | **POST** /v2/flows/{flow_id}/generate-commit-msg | Generate Commit Message
*FlowsApi* | [**get**](docs/FlowsApi.md#get) | **GET** /v2/flows/{flow_id} | Get
*FlowsApi* | [**get_all_components**](docs/FlowsApi.md#get_all_components) | **GET** /v2/flows/components/all | Get All Components
*FlowsApi* | [**get_attachments**](docs/FlowsApi.md#get_attachments) | **GET** /v2/flows/sessions/{session_id}/attachments | Get Attachments
*FlowsApi* | [**get_flow_versions**](docs/FlowsApi.md#get_flow_versions) | **GET** /v2/flows/{flow_id}/version_history | Get Flow Versions
*FlowsApi* | [**get_invoked_flow_results**](docs/FlowsApi.md#get_invoked_flow_results) | **GET** /v2/flows/{flow_id}/{task_id} | Get Invoked Flow Results
*FlowsApi* | [**get_public_flow**](docs/FlowsApi.md#get_public_flow) | **GET** /v2/flows/public/{flow_id} | Get Public Flow
*FlowsApi* | [**get_trigger_types**](docs/FlowsApi.md#get_trigger_types) | **POST** /v2/flows/{flow_id}/triggers | Get Trigger Types
*FlowsApi* | [**invoke_flow**](docs/FlowsApi.md#invoke_flow) | **POST** /v2/flows/{flow_id}/invoke | Invoke Flow
*FlowsApi* | [**invoke_flow_response**](docs/FlowsApi.md#invoke_flow_response) | **POST** /v2/flows/sessions/{session_id}/invoke | Invoke Flow Response
*FlowsApi* | [**invoke_flow_singleton**](docs/FlowsApi.md#invoke_flow_singleton) | **POST** /v2/flows/{flow_id}/invoke_singleton | Invoke Flow Singleton
*FlowsApi* | [**poll_flow_response**](docs/FlowsApi.md#poll_flow_response) | **POST** /v2/flows/sessions/{session_id}/invocation_response/{from_timestamp} | Poll Flow Response
*FlowsApi* | [**publish_flow**](docs/FlowsApi.md#publish_flow) | **POST** /v2/flows/{flow_id}/publish | Publish Flow
*FlowsApi* | [**restore_flow_version**](docs/FlowsApi.md#restore_flow_version) | **POST** /v2/flows/{flow_id}/version_history/{branch}/restore | Restore Flow Version
*FlowsApi* | [**search**](docs/FlowsApi.md#search) | **POST** /v2/flows/ | Search
*FlowsApi* | [**search_all**](docs/FlowsApi.md#search_all) | **POST** /v2/flows/all | Search All
*FlowsApi* | [**search_flow_categories**](docs/FlowsApi.md#search_flow_categories) | **POST** /v2/flows/categories/search | Search Flow Categories
*FlowsApi* | [**search_flow_crons**](docs/FlowsApi.md#search_flow_crons) | **POST** /v2/flows/crons/search | Search Flow Crons
*FlowsApi* | [**update_flow**](docs/FlowsApi.md#update_flow) | **PUT** /v2/flows/{flow_id} | Update Flow
*FlowsApi* | [**update_flow_category**](docs/FlowsApi.md#update_flow_category) | **PUT** /v2/flows/categories/{cat_id} | Update Flow Category
*FlowsApi* | [**update_flow_cron**](docs/FlowsApi.md#update_flow_cron) | **PUT** /v2/flows/crons/{flow_id}/{cron_id} | Update Flow Cron
*FlowsApi* | [**upload_attachments**](docs/FlowsApi.md#upload_attachments) | **POST** /v2/flows/sessions/{session_id}/attachments | Upload Attachments
*GoogleApi* | [**get_calendars**](docs/GoogleApi.md#get_calendars) | **GET** /v2/integrations/google/calendar | Get Calendars
*GoogleApi* | [**get_picker_token**](docs/GoogleApi.md#get_picker_token) | **GET** /v2/integrations/google/picker_token | Get Picker Token
*GoogleApi* | [**get_sheets**](docs/GoogleApi.md#get_sheets) | **GET** /v2/integrations/google/sheets/{document_id} | Get Sheets
*GoogleAdsApi* | [**add_keyword_to_group**](docs/GoogleAdsApi.md#add_keyword_to_group) | **POST** /v2/integrations/google_ads/keyword/add_to_group | Add Keyword To Group
*GoogleAdsApi* | [**analyze_not_assigned_keywords**](docs/GoogleAdsApi.md#analyze_not_assigned_keywords) | **POST** /v2/integrations/google_ads/analyze_not_assigned_keywords | Analyze Not Assigned Keywords
*GoogleAdsApi* | [**get_google_ads_campaigns**](docs/GoogleAdsApi.md#get_google_ads_campaigns) | **POST** /v2/integrations/google_ads/campaigns | Get Google Ads Campaigns
*GoogleAdsApi* | [**get_google_ads_customers**](docs/GoogleAdsApi.md#get_google_ads_customers) | **POST** /v2/integrations/google_ads/customers | Get Google Ads Customers
*GoogleAdsApi* | [**get_google_ads_groups**](docs/GoogleAdsApi.md#get_google_ads_groups) | **POST** /v2/integrations/google_ads/groups | Get Google Ads Groups
*GoogleAdsApi* | [**get_recommendations**](docs/GoogleAdsApi.md#get_recommendations) | **POST** /v2/integrations/google_ads/recommendations/ | Get Recommendations
*GoogleAdsApi* | [**import_google_ads_campaigns**](docs/GoogleAdsApi.md#import_google_ads_campaigns) | **POST** /v2/integrations/google_ads/campaigns/import | Import Google Ads Campaigns
*GoogleAdsApi* | [**import_google_ads_customers**](docs/GoogleAdsApi.md#import_google_ads_customers) | **POST** /v2/integrations/google_ads/customers/import | Import Google Ads Customers
*GoogleAdsApi* | [**import_google_ads_groups**](docs/GoogleAdsApi.md#import_google_ads_groups) | **POST** /v2/integrations/google_ads/groups/import | Import Google Ads Groups
*GoogleAdsApi* | [**remove_keyword_from_group**](docs/GoogleAdsApi.md#remove_keyword_from_group) | **POST** /v2/integrations/google_ads/keyword/remove_from_group | Remove Keyword From Group
*GoogleAdsApi* | [**update_google_ads_campaign**](docs/GoogleAdsApi.md#update_google_ads_campaign) | **PUT** /v2/integrations/google_ads/campaigns/{customer_id}/{campaign_id} | Update Google Ads Campaign
*GoogleAdsApi* | [**update_google_ads_customer_update**](docs/GoogleAdsApi.md#update_google_ads_customer_update) | **PUT** /v2/integrations/google_ads/customers/{customer_id} | Update Google Ads Customer Update
*GoogleAdsApi* | [**update_google_ads_group**](docs/GoogleAdsApi.md#update_google_ads_group) | **PUT** /v2/integrations/google_ads/groups/{customer_id}/{campaign_id}/{group_id} | Update Google Ads Group
*HealthApi* | [**health**](docs/HealthApi.md#health) | **GET** /v2/monitoring/health/ | Health
*HubSpotApi* | [**get_actors**](docs/HubSpotApi.md#get_actors) | **GET** /v2/integrations/hubspot/actors/ | Get Actors
*ImagesApi* | [**convert_image**](docs/ImagesApi.md#convert_image) | **POST** /v2/images/convert | Convert Image
*ImagesApi* | [**get_screenshot**](docs/ImagesApi.md#get_screenshot) | **POST** /v2/images/screenshot | Get Screenshot
*ImagesApi* | [**optimize_image**](docs/ImagesApi.md#optimize_image) | **POST** /v2/images/optimize | Optimize Image
*InstagramApi* | [**get_profile_information**](docs/InstagramApi.md#get_profile_information) | **GET** /v2/integrations/instagram/profile_information | Get Profile Information
*IntegrationsApi* | [**create_integration**](docs/IntegrationsApi.md#create_integration) | **POST** /v2/integrations/{slug}/integrate | Create Integration
*IntegrationsApi* | [**customer_data_request**](docs/IntegrationsApi.md#customer_data_request) | **POST** /v2/integrations/shopify/webhooks/customers/data_request | Customer Data Request
*IntegrationsApi* | [**customer_redact**](docs/IntegrationsApi.md#customer_redact) | **POST** /v2/integrations/shopify/webhooks/customers/redact | Customer Redact
*IntegrationsApi* | [**delete_integration**](docs/IntegrationsApi.md#delete_integration) | **DELETE** /v2/integrations/{slug}/{integration_id} | Delete Integration
*IntegrationsApi* | [**get_actors**](docs/IntegrationsApi.md#get_actors) | **GET** /v2/integrations/hubspot/actors/ | Get Actors
*IntegrationsApi* | [**get_all_integrations**](docs/IntegrationsApi.md#get_all_integrations) | **GET** /v2/integrations/all | Get All Integrations
*IntegrationsApi* | [**get_calendars**](docs/IntegrationsApi.md#get_calendars) | **GET** /v2/integrations/google/calendar | Get Calendars
*IntegrationsApi* | [**get_integration**](docs/IntegrationsApi.md#get_integration) | **GET** /v2/integrations/{slug}/{integration_id} | Get Integration
*IntegrationsApi* | [**get_picker_token**](docs/IntegrationsApi.md#get_picker_token) | **GET** /v2/integrations/google/picker_token | Get Picker Token
*IntegrationsApi* | [**get_profile_information**](docs/IntegrationsApi.md#get_profile_information) | **GET** /v2/integrations/instagram/profile_information | Get Profile Information
*IntegrationsApi* | [**get_sheets**](docs/IntegrationsApi.md#get_sheets) | **GET** /v2/integrations/google/sheets/{document_id} | Get Sheets
*IntegrationsApi* | [**get_slack_channels**](docs/IntegrationsApi.md#get_slack_channels) | **GET** /v2/integrations/slack/{slack_team_id}/channels | Get Slack Channels
*IntegrationsApi* | [**get_slack_workspaces**](docs/IntegrationsApi.md#get_slack_workspaces) | **GET** /v2/integrations/slack/ | Get Slack Workspaces
*IntegrationsApi* | [**get_wordpress_post_categories**](docs/IntegrationsApi.md#get_wordpress_post_categories) | **GET** /v2/integrations/wordpress/{integration_id}/categories | Get Wordpress Post Categories
*IntegrationsApi* | [**get_wordpress_post_tags**](docs/IntegrationsApi.md#get_wordpress_post_tags) | **GET** /v2/integrations/wordpress/{integration_id}/tags | Get Wordpress Post Tags
*IntegrationsApi* | [**get_wordpress_sites**](docs/IntegrationsApi.md#get_wordpress_sites) | **GET** /v2/integrations/wordpress/sites | Get Wordpress Sites
*IntegrationsApi* | [**integration_callback**](docs/IntegrationsApi.md#integration_callback) | **GET** /v2/integrations/{slug}/callback | Integration Callback
*IntegrationsApi* | [**search_integrations**](docs/IntegrationsApi.md#search_integrations) | **POST** /v2/integrations/{slug} | Search Integrations
*IntegrationsApi* | [**shop_redact**](docs/IntegrationsApi.md#shop_redact) | **POST** /v2/integrations/shopify/webhooks/shop/redact | Shop Redact
*IntegrationsApi* | [**update_admin_consent**](docs/IntegrationsApi.md#update_admin_consent) | **POST** /v2/integrations/microsoft_entra_id/admin_consent | Update Admin Consent
*LogsApi* | [**search_logs**](docs/LogsApi.md#search_logs) | **POST** /v2/logs/search | Search logs
*MCPServersApi* | [**create_mcp_server**](docs/MCPServersApi.md#create_mcp_server) | **POST** /v2/mcp_servers/create | Create Mcp Server
*MCPServersApi* | [**delete_mcp_server**](docs/MCPServersApi.md#delete_mcp_server) | **DELETE** /v2/mcp_servers/{mcp_server_id} | Delete Mcp Server
*MCPServersApi* | [**get_all_mcp_subservers**](docs/MCPServersApi.md#get_all_mcp_subservers) | **GET** /v2/mcp_servers/all | Get All Mcp Subservers
*MCPServersApi* | [**get_mcp_server**](docs/MCPServersApi.md#get_mcp_server) | **GET** /v2/mcp_servers/{mcp_server_id} | Get Mcp Server
*MCPServersApi* | [**search_mcp_servers**](docs/MCPServersApi.md#search_mcp_servers) | **POST** /v2/mcp_servers/ | Search Mcp Servers
*MCPServersApi* | [**update_mcp_server**](docs/MCPServersApi.md#update_mcp_server) | **PUT** /v2/mcp_servers/{mcp_server_id} | Update Mcp Server
*MediaApi* | [**get_transcript**](docs/MediaApi.md#get_transcript) | **POST** /v2/media/transcript | Get Transcript
*MediaApi* | [**get_transcript_result**](docs/MediaApi.md#get_transcript_result) | **POST** /v2/media/transcript_status | Get Transcript Result
*MediaApi* | [**get_youtube_transcript**](docs/MediaApi.md#get_youtube_transcript) | **POST** /v2/media/youtube/transcript | Get Youtube Transcript
*MicrosoftOutlookApi* | [**update_admin_consent**](docs/MicrosoftOutlookApi.md#update_admin_consent) | **POST** /v2/integrations/microsoft_entra_id/admin_consent | Update Admin Consent
*OAuthApi* | [**oauth_authorize**](docs/OAuthApi.md#oauth_authorize) | **GET** /v2/auth/oauth/authorize | Oauth Authorize
*OAuthApi* | [**oauth_authorize_post**](docs/OAuthApi.md#oauth_authorize_post) | **POST** /v2/auth/oauth/authorize | Oauth Authorize Post
*OAuthApi* | [**oauth_callback**](docs/OAuthApi.md#oauth_callback) | **GET** /v2/auth/oauth/callback | Oauth Callback
*OAuthApi* | [**oauth_login**](docs/OAuthApi.md#oauth_login) | **GET** /v2/auth/oauth/login | Oauth Login
*OAuthApi* | [**oauth_login_github**](docs/OAuthApi.md#oauth_login_github) | **GET** /v2/auth/oauth/login/github | Oauth Login Github
*OAuthApi* | [**oauth_login_google**](docs/OAuthApi.md#oauth_login_google) | **GET** /v2/auth/oauth/login/google | Oauth Login Google
*OAuthApi* | [**oauth_login_post**](docs/OAuthApi.md#oauth_login_post) | **POST** /v2/auth/oauth/login | Oauth Login Post
*OAuthApi* | [**oauth_login_shopify**](docs/OAuthApi.md#oauth_login_shopify) | **GET** /v2/auth/oauth/login/shopify | Oauth Login Shopify
*OAuthApi* | [**oauth_logout**](docs/OAuthApi.md#oauth_logout) | **GET** /v2/auth/oauth/logout | Oauth Logout
*OAuthApi* | [**oauth_revoke**](docs/OAuthApi.md#oauth_revoke) | **POST** /v2/auth/oauth/revoke | Oauth Revoke
*OAuthApi* | [**oauth_token**](docs/OAuthApi.md#oauth_token) | **POST** /v2/auth/oauth/token | Oauth Token
*OAuthApi* | [**oauth_userinfo**](docs/OAuthApi.md#oauth_userinfo) | **GET** /v2/auth/oauth/userinfo | Oauth Userinfo
*OAuthApi* | [**saml_callback**](docs/OAuthApi.md#saml_callback) | **POST** /v2/auth/oauth/callback/saml/{random_id} | Saml Callback
*ObservabilityDriverApi* | [**activate_langfuse_observability_driver**](docs/ObservabilityDriverApi.md#activate_langfuse_observability_driver) | **POST** /v2/observability_driver/langfuse | Activate Langfuse Observability Driver
*ObservabilityDriverApi* | [**delete_observability_driver**](docs/ObservabilityDriverApi.md#delete_observability_driver) | **DELETE** /v2/observability_driver/{driver_type} | Delete Observability Driver
*ObservabilityDriverApi* | [**get_observability_driver**](docs/ObservabilityDriverApi.md#get_observability_driver) | **GET** /v2/observability_driver/{driver_type} | Get Observability Driver
*ObservabilityDriverApi* | [**get_observability_driver_workspace**](docs/ObservabilityDriverApi.md#get_observability_driver_workspace) | **POST** /v2/observability_driver/ | Get Observability Driver Workspace
*ObservabilityDriverApi* | [**update_langfuse_observability_driver**](docs/ObservabilityDriverApi.md#update_langfuse_observability_driver) | **PUT** /v2/observability_driver/langfuse | Update Langfuse Observability Driver
*PhotoAIApi* | [**explore**](docs/PhotoAIApi.md#explore) | **GET** /v2/photo_ai/public/explore | Explore
*PhotoAIApi* | [**get_effects**](docs/PhotoAIApi.md#get_effects) | **GET** /v2/photo_ai/public/effects | Get Effects
*PhotoAIApi* | [**get_styles**](docs/PhotoAIApi.md#get_styles) | **GET** /v2/photo_ai/public/styles | Get Styles
*PhotoAIApi* | [**get_templates**](docs/PhotoAIApi.md#get_templates) | **GET** /v2/photo_ai/public/templates | Get Templates
*PromptsApi* | [**create_prompt**](docs/PromptsApi.md#create_prompt) | **POST** /v2/prompts/create | Create Prompt
*PromptsApi* | [**create_prompt_category**](docs/PromptsApi.md#create_prompt_category) | **POST** /v2/prompts/categories/create | Create Prompt Category
*PromptsApi* | [**delete_prompt**](docs/PromptsApi.md#delete_prompt) | **DELETE** /v2/prompts/{prompt_id} | Delete Prompt
*PromptsApi* | [**delete_prompt_category**](docs/PromptsApi.md#delete_prompt_category) | **DELETE** /v2/prompts/categories/{cat_id} | Delete Prompt Category
*PromptsApi* | [**search_prompt_categories**](docs/PromptsApi.md#search_prompt_categories) | **POST** /v2/prompts/categories/search | Search Prompt Categories
*PromptsApi* | [**search_prompts**](docs/PromptsApi.md#search_prompts) | **POST** /v2/prompts/search | Search Prompts
*PromptsApi* | [**update_prompt**](docs/PromptsApi.md#update_prompt) | **PUT** /v2/prompts/{prompt_id} | Update Prompt
*PromptsApi* | [**update_prompt_category**](docs/PromptsApi.md#update_prompt_category) | **PUT** /v2/prompts/categories/{cat_id} | Update Prompt Category
*SERPApi* | [**search_cluster_query**](docs/SERPApi.md#search_cluster_query) | **POST** /v2/serp/clusters/keywords | Search Cluster Query
*SERPApi* | [**serp_cluster_add_queries**](docs/SERPApi.md#serp_cluster_add_queries) | **POST** /v2/serp/clusters/{customer_id}/{campaign_id}/{group_id}/add_keywords | Serp Cluster Add Queries
*SERPApi* | [**serp_cluster_delete_campaign**](docs/SERPApi.md#serp_cluster_delete_campaign) | **DELETE** /v2/serp/clusters/{customer_id}/{campaign_id} | Serp Cluster Delete Campaign
*SERPApi* | [**serp_cluster_delete_customer**](docs/SERPApi.md#serp_cluster_delete_customer) | **DELETE** /v2/serp/clusters/{customer_id} | Serp Cluster Delete Customer
*SERPApi* | [**serp_cluster_delete_group**](docs/SERPApi.md#serp_cluster_delete_group) | **DELETE** /v2/serp/clusters/{customer_id}/{campaign_id}/{group_id} | Serp Cluster Delete Group
*SERPApi* | [**serp_cluster_delete_group_queries**](docs/SERPApi.md#serp_cluster_delete_group_queries) | **DELETE** /v2/serp/clusters/{customer_id}/{campaign_id}/{group_id}/delete_queries | Serp Cluster Delete Group Queries
*SERPApi* | [**serp_cluster_get_graph_nodes**](docs/SERPApi.md#serp_cluster_get_graph_nodes) | **POST** /v2/serp/clusters/graph_nodes | Serp Cluster Get Graph Nodes
*SERPApi* | [**serp_cluster_get_matching_groups_to_query**](docs/SERPApi.md#serp_cluster_get_matching_groups_to_query) | **POST** /v2/serp/clusters/recommended_groups | Serp Cluster Get Matching Groups To Query
*SERPApi* | [**serp_cluster_get_related_keywords_to_query**](docs/SERPApi.md#serp_cluster_get_related_keywords_to_query) | **POST** /v2/serp/clusters/related_keywords | Serp Cluster Get Related Keywords To Query
*SERPApi* | [**serp_cluster_split_to_sub_clusters**](docs/SERPApi.md#serp_cluster_split_to_sub_clusters) | **POST** /v2/serp/clusters/split_sub_clusters | Serp Cluster Split To Sub Clusters
*SERPApi* | [**serp_search**](docs/SERPApi.md#serp_search) | **POST** /v2/serp/serp/search | Serp Search
*SERPApi* | [**serp_volumes**](docs/SERPApi.md#serp_volumes) | **POST** /v2/serp/serp/volumes | Serp Volumes
*SERPApi* | [**serp_volumes_pingback**](docs/SERPApi.md#serp_volumes_pingback) | **GET** /v2/serp/serp/volumes/pingback/{id}/{tag} | Serp Volumes Pingback
*SchedulesApi* | [**create_schedules**](docs/SchedulesApi.md#create_schedules) | **POST** /v2/schedules/create | Create Schedules
*SchedulesApi* | [**delete_schedule**](docs/SchedulesApi.md#delete_schedule) | **DELETE** /v2/schedules/{schedule_id} | Delete Schedule
*SchedulesApi* | [**get_schedule**](docs/SchedulesApi.md#get_schedule) | **GET** /v2/schedules/{schedule_id} | Get Schedule
*SchedulesApi* | [**get_schedule_url_details**](docs/SchedulesApi.md#get_schedule_url_details) | **GET** /v2/schedules/{schedule_id}/urls/{domain_id}/{url_id} | Get Schedule Url Details
*SchedulesApi* | [**get_schedules**](docs/SchedulesApi.md#get_schedules) | **POST** /v2/schedules/ | Get Schedules
*SchedulesApi* | [**run_schedule**](docs/SchedulesApi.md#run_schedule) | **POST** /v2/schedules/run/{schedule_id} | Run Schedule
*SchedulesApi* | [**search_schedule_urls**](docs/SchedulesApi.md#search_schedule_urls) | **POST** /v2/schedules/urls/ | Search Schedule Urls
*SchedulesApi* | [**update_schedule**](docs/SchedulesApi.md#update_schedule) | **PUT** /v2/schedules/{schedule_id} | Update Schedule
*SecretsApi* | [**create_secret**](docs/SecretsApi.md#create_secret) | **POST** /v2/secrets/create | Create Secret
*SecretsApi* | [**delete_secret**](docs/SecretsApi.md#delete_secret) | **DELETE** /v2/secrets/{secret_id} | Delete Secret
*SecretsApi* | [**get_secret**](docs/SecretsApi.md#get_secret) | **GET** /v2/secrets/{secret_id} | Get Secret
*SecretsApi* | [**search_secret**](docs/SecretsApi.md#search_secret) | **POST** /v2/secrets/search | Search Secret
*SecretsApi* | [**update_secret**](docs/SecretsApi.md#update_secret) | **PUT** /v2/secrets/{secret_id} | Update Secret
*SemanticSearchApi* | [**get_similar_docs_by_doc_id**](docs/SemanticSearchApi.md#get_similar_docs_by_doc_id) | **POST** /v2/similarities/document/live | Get Similar Docs By Doc Id
*SemanticSearchApi* | [**get_similar_docs_by_query**](docs/SemanticSearchApi.md#get_similar_docs_by_query) | **POST** /v2/similarities/query/live | Get Similar Docs By Query
*SemanticSearchApi* | [**schedule_similar_docs_by_doc_id**](docs/SemanticSearchApi.md#schedule_similar_docs_by_doc_id) | **POST** /v2/similarities/document | Schedule Similar Docs By Doc Id
*SemanticSearchApi* | [**schedule_similar_docs_by_query**](docs/SemanticSearchApi.md#schedule_similar_docs_by_query) | **POST** /v2/similarities/query | Schedule Similar Docs By Query
*ShopifyApi* | [**customer_data_request**](docs/ShopifyApi.md#customer_data_request) | **POST** /v2/integrations/shopify/webhooks/customers/data_request | Customer Data Request
*ShopifyApi* | [**customer_redact**](docs/ShopifyApi.md#customer_redact) | **POST** /v2/integrations/shopify/webhooks/customers/redact | Customer Redact
*ShopifyApi* | [**shop_redact**](docs/ShopifyApi.md#shop_redact) | **POST** /v2/integrations/shopify/webhooks/shop/redact | Shop Redact
*SlackApi* | [**get_slack_channels**](docs/SlackApi.md#get_slack_channels) | **GET** /v2/integrations/slack/{slack_team_id}/channels | Get Slack Channels
*SlackApi* | [**get_slack_workspaces**](docs/SlackApi.md#get_slack_workspaces) | **GET** /v2/integrations/slack/ | Get Slack Workspaces
*TagsApi* | [**create_tag**](docs/TagsApi.md#create_tag) | **POST** /v2/tags/create | Create Tag
*TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /v2/tags/{tag_id} | Delete Tag
*TagsApi* | [**search_tags**](docs/TagsApi.md#search_tags) | **POST** /v2/tags/search | Search Tags
*TagsApi* | [**update_tag**](docs/TagsApi.md#update_tag) | **PUT** /v2/tags/{tag_id} | Update Tag
*TrackingApi* | [**search_events**](docs/TrackingApi.md#search_events) | **POST** /v2/tracking/events | Search Events
*TrackingApi* | [**search_links**](docs/TrackingApi.md#search_links) | **POST** /v2/tracking/links | Search Links
*TrackingApi* | [**search_sources**](docs/TrackingApi.md#search_sources) | **POST** /v2/tracking/sources | Search Sources
*TrackingApi* | [**track_click**](docs/TrackingApi.md#track_click) | **POST** /v2/tracking/clk | Track Click
*TrackingApi* | [**track_event**](docs/TrackingApi.md#track_event) | **POST** /v2/tracking/evnt | Track Event
*TrackingApi* | [**track_link**](docs/TrackingApi.md#track_link) | **POST** /v2/tracking/lnk | Track Link
*WebAuthApi* | [**activate_account**](docs/WebAuthApi.md#activate_account) | **GET** /v2/auth/activate | Activate Account
*WebAuthApi* | [**get_user**](docs/WebAuthApi.md#get_user) | **GET** /v2/auth/me | Get User
*WebAuthApi* | [**password_recovery_page**](docs/WebAuthApi.md#password_recovery_page) | **GET** /v2/auth/recover-password | Password Recovery Page
*WebAuthApi* | [**password_recovery_submit**](docs/WebAuthApi.md#password_recovery_submit) | **POST** /v2/auth/recover-password | Password Recovery Submit
*WebAuthApi* | [**register_page**](docs/WebAuthApi.md#register_page) | **GET** /v2/auth/register | Register Page
*WebAuthApi* | [**register_submit**](docs/WebAuthApi.md#register_submit) | **POST** /v2/auth/register | Register Submit
*WebAuthApi* | [**reset_password_page**](docs/WebAuthApi.md#reset_password_page) | **GET** /v2/auth/reset-password | Reset Password Page
*WebAuthApi* | [**reset_password_submit**](docs/WebAuthApi.md#reset_password_submit) | **POST** /v2/auth/reset-password | Reset Password Submit
*WebAuthApi* | [**sso_login_page**](docs/WebAuthApi.md#sso_login_page) | **GET** /v2/auth/oauth/sso | Sso Login Page
*WebAuthApi* | [**sso_login_submit**](docs/WebAuthApi.md#sso_login_submit) | **POST** /v2/auth/oauth/sso | Sso Login Submit
*WordPressApi* | [**get_wordpress_post_categories**](docs/WordPressApi.md#get_wordpress_post_categories) | **GET** /v2/integrations/wordpress/{integration_id}/categories | Get Wordpress Post Categories
*WordPressApi* | [**get_wordpress_post_tags**](docs/WordPressApi.md#get_wordpress_post_tags) | **GET** /v2/integrations/wordpress/{integration_id}/tags | Get Wordpress Post Tags
*WordPressApi* | [**get_wordpress_sites**](docs/WordPressApi.md#get_wordpress_sites) | **GET** /v2/integrations/wordpress/sites | Get Wordpress Sites
*WorkspacesApi* | [**add_workspace_user**](docs/WorkspacesApi.md#add_workspace_user) | **POST** /v2/workspaces/{workspace_id}/add-member | Add Workspace User
*WorkspacesApi* | [**create_workspace**](docs/WorkspacesApi.md#create_workspace) | **POST** /v2/workspaces/create | Create Workspace
*WorkspacesApi* | [**delete_workspace**](docs/WorkspacesApi.md#delete_workspace) | **DELETE** /v2/workspaces/{workspace_id} | Delete Workspace
*WorkspacesApi* | [**delete_workspace_user**](docs/WorkspacesApi.md#delete_workspace_user) | **DELETE** /v2/workspaces/{workspace_id}/{user_id} | Delete Workspace User
*WorkspacesApi* | [**get_workspace**](docs/WorkspacesApi.md#get_workspace) | **POST** /v2/workspaces/{workspace_id} | Get Workspace
*WorkspacesApi* | [**search_my_workspaces**](docs/WorkspacesApi.md#search_my_workspaces) | **POST** /v2/workspaces/me/my_workspaces | Search My Workspaces
*WorkspacesApi* | [**search_workspace_users**](docs/WorkspacesApi.md#search_workspace_users) | **POST** /v2/workspaces/{workspace_id}/users | Search Workspace Users
*WorkspacesApi* | [**update_workspace**](docs/WorkspacesApi.md#update_workspace) | **PUT** /v2/workspaces/{workspace_id} | Update Workspace
*WorkspacesApi* | [**update_workspace_user**](docs/WorkspacesApi.md#update_workspace_user) | **PUT** /v2/workspaces/{workspace_id}/{user_id} | Update Workspace User
*WorkspacesSSOApi* | [**create_workspace_sso_settings**](docs/WorkspacesSSOApi.md#create_workspace_sso_settings) | **POST** /v2/workspaces/{workspace_id}/sso | Create Workspace Sso Settings
*WorkspacesSSOApi* | [**delete_workspace_sso_settings**](docs/WorkspacesSSOApi.md#delete_workspace_sso_settings) | **DELETE** /v2/workspaces/{workspace_id}/sso/{provider} | Delete Workspace Sso Settings
*WorkspacesSSOApi* | [**get_workspace_sso_settings**](docs/WorkspacesSSOApi.md#get_workspace_sso_settings) | **GET** /v2/workspaces/{workspace_id}/sso/{provider} | Get Workspace Sso Settings
*WorkspacesSSOApi* | [**list_workspace_sso_settings**](docs/WorkspacesSSOApi.md#list_workspace_sso_settings) | **GET** /v2/workspaces/{workspace_id}/sso | List Workspace Sso Settings
*WorkspacesSSOApi* | [**update_workspace_sso_settings**](docs/WorkspacesSSOApi.md#update_workspace_sso_settings) | **PUT** /v2/workspaces/{workspace_id}/sso/{provider} | Update Workspace Sso Settings
*WorkspacesSSODomainVerificationApi* | [**create_domain_verification**](docs/WorkspacesSSODomainVerificationApi.md#create_domain_verification) | **POST** /v2/workspaces/{workspace_id}/sso/domain-verification | Create Domain Verification
*WorkspacesSSODomainVerificationApi* | [**delete_domain_verification**](docs/WorkspacesSSODomainVerificationApi.md#delete_domain_verification) | **DELETE** /v2/workspaces/{workspace_id}/sso/domain-verification | Delete Domain Verification
*WorkspacesSSODomainVerificationApi* | [**list_domain_verifications**](docs/WorkspacesSSODomainVerificationApi.md#list_domain_verifications) | **GET** /v2/workspaces/{workspace_id}/sso/domain-verification | List Domain Verifications
*WorkspacesSSODomainVerificationApi* | [**verify_domain**](docs/WorkspacesSSODomainVerificationApi.md#verify_domain) | **POST** /v2/workspaces/{workspace_id}/sso/domain-verification/verify | Verify Domain


## Documentation For Models

 - [AllFlowsSearchRequest](docs/AllFlowsSearchRequest.md)
 - [ApiKeyCreateRequest](docs/ApiKeyCreateRequest.md)
 - [ApiKeyResponse](docs/ApiKeyResponse.md)
 - [ApiKeySearchRequest](docs/ApiKeySearchRequest.md)
 - [ApiKeyUpdateRequest](docs/ApiKeyUpdateRequest.md)
 - [AppUrlInput](docs/AppUrlInput.md)
 - [AppUrlOutput](docs/AppUrlOutput.md)
 - [AspecRatio](docs/AspecRatio.md)
 - [BaseFoundationModel](docs/BaseFoundationModel.md)
 - [BoolChar](docs/BoolChar.md)
 - [ChatbotCreateRequest](docs/ChatbotCreateRequest.md)
 - [ChatbotResponse](docs/ChatbotResponse.md)
 - [ChatbotSearchRequest](docs/ChatbotSearchRequest.md)
 - [ChatbotStatus](docs/ChatbotStatus.md)
 - [ChatbotUpdateRequest](docs/ChatbotUpdateRequest.md)
 - [CheckoutCreateRequest](docs/CheckoutCreateRequest.md)
 - [CommunityImageGenerationsResponse](docs/CommunityImageGenerationsResponse.md)
 - [Completed](docs/Completed.md)
 - [CreditBalanceResponse](docs/CreditBalanceResponse.md)
 - [CreditDailyTransactionResponse](docs/CreditDailyTransactionResponse.md)
 - [CreditDailyTransactionSearchRequest](docs/CreditDailyTransactionSearchRequest.md)
 - [CreditTransactionResponse](docs/CreditTransactionResponse.md)
 - [CreditTransactionSearchRequest](docs/CreditTransactionSearchRequest.md)
 - [CustomerDataRequestPayload](docs/CustomerDataRequestPayload.md)
 - [CustomerRedactPayload](docs/CustomerRedactPayload.md)
 - [Data](docs/Data.md)
 - [DocumentCategoryCreateRequest](docs/DocumentCategoryCreateRequest.md)
 - [DocumentCategoryResponse](docs/DocumentCategoryResponse.md)
 - [DocumentCategorySearchRequest](docs/DocumentCategorySearchRequest.md)
 - [DocumentCategoryUpdateRequest](docs/DocumentCategoryUpdateRequest.md)
 - [DocumentContent](docs/DocumentContent.md)
 - [DocumentContentResponse](docs/DocumentContentResponse.md)
 - [DocumentResponse](docs/DocumentResponse.md)
 - [DocumentSearchRequest](docs/DocumentSearchRequest.md)
 - [DocumentSimilarityRequest](docs/DocumentSimilarityRequest.md)
 - [DocumentSimilarityTaskRequest](docs/DocumentSimilarityTaskRequest.md)
 - [DocumentStatus](docs/DocumentStatus.md)
 - [DocumentType](docs/DocumentType.md)
 - [DocumentUpdateRequest](docs/DocumentUpdateRequest.md)
 - [DriverSuccessResponse](docs/DriverSuccessResponse.md)
 - [DriverType](docs/DriverType.md)
 - [FTStatus](docs/FTStatus.md)
 - [FTType](docs/FTType.md)
 - [FaqCreateRequest](docs/FaqCreateRequest.md)
 - [FaqResponse](docs/FaqResponse.md)
 - [FaqSearchRequest](docs/FaqSearchRequest.md)
 - [FaqStatus](docs/FaqStatus.md)
 - [FaqType](docs/FaqType.md)
 - [FaqUpdateRequest](docs/FaqUpdateRequest.md)
 - [FeatureResponse](docs/FeatureResponse.md)
 - [FileUploadResponse](docs/FileUploadResponse.md)
 - [FlowAssistantAIModel](docs/FlowAssistantAIModel.md)
 - [FlowAssistantAddComponentMetadata](docs/FlowAssistantAddComponentMetadata.md)
 - [FlowAssistantAddConnectionMetadata](docs/FlowAssistantAddConnectionMetadata.md)
 - [FlowAssistantApplyRejectChangesRequest](docs/FlowAssistantApplyRejectChangesRequest.md)
 - [FlowAssistantCreateBlankFlowMetadata](docs/FlowAssistantCreateBlankFlowMetadata.md)
 - [FlowAssistantDeleteComponentMetadata](docs/FlowAssistantDeleteComponentMetadata.md)
 - [FlowAssistantDeleteConnectionMetadata](docs/FlowAssistantDeleteConnectionMetadata.md)
 - [FlowAssistantInvokeRequest](docs/FlowAssistantInvokeRequest.md)
 - [FlowAssistantSessionCreateRequest](docs/FlowAssistantSessionCreateRequest.md)
 - [FlowAssistantUpdateComponentMetadata](docs/FlowAssistantUpdateComponentMetadata.md)
 - [FlowBranch](docs/FlowBranch.md)
 - [FlowCategoryCreateRequest](docs/FlowCategoryCreateRequest.md)
 - [FlowCategoryResponse](docs/FlowCategoryResponse.md)
 - [FlowCategorySearchRequest](docs/FlowCategorySearchRequest.md)
 - [FlowCommitRequest](docs/FlowCommitRequest.md)
 - [FlowCommitResponse](docs/FlowCommitResponse.md)
 - [FlowConfig](docs/FlowConfig.md)
 - [FlowCreate](docs/FlowCreate.md)
 - [FlowCronCreateRequest](docs/FlowCronCreateRequest.md)
 - [FlowCronResponse](docs/FlowCronResponse.md)
 - [FlowCronSearchRequest](docs/FlowCronSearchRequest.md)
 - [FlowCronStatus](docs/FlowCronStatus.md)
 - [FlowCronUpdateRequest](docs/FlowCronUpdateRequest.md)
 - [FlowDetailResponse](docs/FlowDetailResponse.md)
 - [FlowEventActionType](docs/FlowEventActionType.md)
 - [FlowHuntProductSlug](docs/FlowHuntProductSlug.md)
 - [FlowInvokeRequest](docs/FlowInvokeRequest.md)
 - [FlowResponse](docs/FlowResponse.md)
 - [FlowSearchRequest](docs/FlowSearchRequest.md)
 - [FlowSessionAttachmentResponse](docs/FlowSessionAttachmentResponse.md)
 - [FlowSessionCreateFromFlowRequest](docs/FlowSessionCreateFromFlowRequest.md)
 - [FlowSessionCreateRequest](docs/FlowSessionCreateRequest.md)
 - [FlowSessionEvent](docs/FlowSessionEvent.md)
 - [FlowSessionInvocationResponse](docs/FlowSessionInvocationResponse.md)
 - [FlowSessionInvokeRequest](docs/FlowSessionInvokeRequest.md)
 - [FlowSessionLoadingMetadata](docs/FlowSessionLoadingMetadata.md)
 - [FlowSessionMessageMetadata](docs/FlowSessionMessageMetadata.md)
 - [FlowSessionResponse](docs/FlowSessionResponse.md)
 - [FlowSessionTaskResponseMetadata](docs/FlowSessionTaskResponseMetadata.md)
 - [FlowSessionToolCallMetadata](docs/FlowSessionToolCallMetadata.md)
 - [FlowSessionViewResponse](docs/FlowSessionViewResponse.md)
 - [FlowSessionViewSearchRequest](docs/FlowSessionViewSearchRequest.md)
 - [FlowSessionViewUpdateRequest](docs/FlowSessionViewUpdateRequest.md)
 - [FlowType](docs/FlowType.md)
 - [FlowUpdate](docs/FlowUpdate.md)
 - [FlowVersionHistoryResponse](docs/FlowVersionHistoryResponse.md)
 - [GeneralMCPSubserverCapabilitiesResponse](docs/GeneralMCPSubserverCapabilitiesResponse.md)
 - [GeneralMCPSubserverResponse](docs/GeneralMCPSubserverResponse.md)
 - [GoogleAdsActionType](docs/GoogleAdsActionType.md)
 - [GoogleAdsAnalyzeKeywordsRequest](docs/GoogleAdsAnalyzeKeywordsRequest.md)
 - [GoogleAdsCampaignResponse](docs/GoogleAdsCampaignResponse.md)
 - [GoogleAdsCampaignStatus](docs/GoogleAdsCampaignStatus.md)
 - [GoogleAdsCampaignUpdateRequest](docs/GoogleAdsCampaignUpdateRequest.md)
 - [GoogleAdsCampaignsResponse](docs/GoogleAdsCampaignsResponse.md)
 - [GoogleAdsCampaignsSearchRequest](docs/GoogleAdsCampaignsSearchRequest.md)
 - [GoogleAdsCustomerResponse](docs/GoogleAdsCustomerResponse.md)
 - [GoogleAdsCustomerUpdateRequest](docs/GoogleAdsCustomerUpdateRequest.md)
 - [GoogleAdsCustomersResponse](docs/GoogleAdsCustomersResponse.md)
 - [GoogleAdsCustomersSearchRequest](docs/GoogleAdsCustomersSearchRequest.md)
 - [GoogleAdsGroupResponse](docs/GoogleAdsGroupResponse.md)
 - [GoogleAdsGroupStatus](docs/GoogleAdsGroupStatus.md)
 - [GoogleAdsGroupUpdateRequest](docs/GoogleAdsGroupUpdateRequest.md)
 - [GoogleAdsGroupsResponse](docs/GoogleAdsGroupsResponse.md)
 - [GoogleAdsGroupsSearchRequest](docs/GoogleAdsGroupsSearchRequest.md)
 - [GoogleAdsKeywordAddRequest](docs/GoogleAdsKeywordAddRequest.md)
 - [GoogleAdsKeywordRecommendation](docs/GoogleAdsKeywordRecommendation.md)
 - [GoogleAdsKeywordRemoveRequest](docs/GoogleAdsKeywordRemoveRequest.md)
 - [GoogleAdsMatchType](docs/GoogleAdsMatchType.md)
 - [GoogleAdsRecommendation](docs/GoogleAdsRecommendation.md)
 - [GoogleAdsRecommendationConfidence](docs/GoogleAdsRecommendationConfidence.md)
 - [GoogleAdsRecommendationStatus](docs/GoogleAdsRecommendationStatus.md)
 - [GoogleAdsRecommendationType](docs/GoogleAdsRecommendationType.md)
 - [GoogleAdsRecommendationsRequest](docs/GoogleAdsRecommendationsRequest.md)
 - [GoogleCalendarResponse](docs/GoogleCalendarResponse.md)
 - [GoogleCalendarsResponse](docs/GoogleCalendarsResponse.md)
 - [GooglePickerTokenResponse](docs/GooglePickerTokenResponse.md)
 - [GoogleSheetResponse](docs/GoogleSheetResponse.md)
 - [GoogleSheetsResponse](docs/GoogleSheetsResponse.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Health](docs/Health.md)
 - [HubSpotActorIdResponse](docs/HubSpotActorIdResponse.md)
 - [HubSpotActorsResponse](docs/HubSpotActorsResponse.md)
 - [ImageConvertRequest](docs/ImageConvertRequest.md)
 - [ImageFTCreateRequest](docs/ImageFTCreateRequest.md)
 - [ImageFTResponse](docs/ImageFTResponse.md)
 - [ImageFTSearchRequest](docs/ImageFTSearchRequest.md)
 - [ImageFTUpdateRequest](docs/ImageFTUpdateRequest.md)
 - [ImageInferenceRequest](docs/ImageInferenceRequest.md)
 - [ImageInferenceResponse](docs/ImageInferenceResponse.md)
 - [ImageInferenceResultResponse](docs/ImageInferenceResultResponse.md)
 - [ImageInferenceScheduleResponse](docs/ImageInferenceScheduleResponse.md)
 - [ImageInferenceScrollResponse](docs/ImageInferenceScrollResponse.md)
 - [ImageOptimizeRequest](docs/ImageOptimizeRequest.md)
 - [ImagePromptGenerationRequest](docs/ImagePromptGenerationRequest.md)
 - [ImagePromptResponse](docs/ImagePromptResponse.md)
 - [InferenceFileType](docs/InferenceFileType.md)
 - [InferenceHistorySearchRequest](docs/InferenceHistorySearchRequest.md)
 - [InstagramProfileInformationResponse](docs/InstagramProfileInformationResponse.md)
 - [IntegrationCategory](docs/IntegrationCategory.md)
 - [IntegrationDetailResponse](docs/IntegrationDetailResponse.md)
 - [IntegrationFlowResponse](docs/IntegrationFlowResponse.md)
 - [IntegrationResponse](docs/IntegrationResponse.md)
 - [IntegrationSearchRequest](docs/IntegrationSearchRequest.md)
 - [IntegrationSlug](docs/IntegrationSlug.md)
 - [LangfuseRequest](docs/LangfuseRequest.md)
 - [LogEntryLevel](docs/LogEntryLevel.md)
 - [LogEntryType](docs/LogEntryType.md)
 - [LogResponse](docs/LogResponse.md)
 - [LogsSearchRequest](docs/LogsSearchRequest.md)
 - [MCPCapabilityBinding](docs/MCPCapabilityBinding.md)
 - [MCPServerCreateRequest](docs/MCPServerCreateRequest.md)
 - [MCPServerResponse](docs/MCPServerResponse.md)
 - [MCPServerSearchRequest](docs/MCPServerSearchRequest.md)
 - [MCPSubServerBinding](docs/MCPSubServerBinding.md)
 - [MessageType](docs/MessageType.md)
 - [Metadata](docs/Metadata.md)
 - [ObservabilityDriverResponse](docs/ObservabilityDriverResponse.md)
 - [Pagination](docs/Pagination.md)
 - [PhotoAIEffectResponse](docs/PhotoAIEffectResponse.md)
 - [PhotoAIStyleResponse](docs/PhotoAIStyleResponse.md)
 - [PhotoAITemplateResponse](docs/PhotoAITemplateResponse.md)
 - [PlanListItemResponse](docs/PlanListItemResponse.md)
 - [PlanResponse](docs/PlanResponse.md)
 - [PointerType](docs/PointerType.md)
 - [PromptCategoryCreateRequest](docs/PromptCategoryCreateRequest.md)
 - [PromptCategoryResponse](docs/PromptCategoryResponse.md)
 - [PromptCategorySearchRequest](docs/PromptCategorySearchRequest.md)
 - [PromptCategoryUpdateRequest](docs/PromptCategoryUpdateRequest.md)
 - [PromptCreateRequest](docs/PromptCreateRequest.md)
 - [PromptResponse](docs/PromptResponse.md)
 - [PromptSearchRequest](docs/PromptSearchRequest.md)
 - [PromptUpdateRequest](docs/PromptUpdateRequest.md)
 - [QuerySimilarityRequest](docs/QuerySimilarityRequest.md)
 - [QuerySimilarityTaskRequest](docs/QuerySimilarityTaskRequest.md)
 - [Role](docs/Role.md)
 - [SamlLoginMethod](docs/SamlLoginMethod.md)
 - [ScheduleCreateRequest](docs/ScheduleCreateRequest.md)
 - [ScheduleFrequency](docs/ScheduleFrequency.md)
 - [ScheduleResponse](docs/ScheduleResponse.md)
 - [ScheduleSearchRequest](docs/ScheduleSearchRequest.md)
 - [ScheduleStatus](docs/ScheduleStatus.md)
 - [ScheduleType](docs/ScheduleType.md)
 - [ScheduleUpdateRequest](docs/ScheduleUpdateRequest.md)
 - [ScheduleUrlDetailResponse](docs/ScheduleUrlDetailResponse.md)
 - [ScheduleUrlResponse](docs/ScheduleUrlResponse.md)
 - [ScheduleUrlSearchRequest](docs/ScheduleUrlSearchRequest.md)
 - [ScreenshotRequest](docs/ScreenshotRequest.md)
 - [ScreenshotResponse](docs/ScreenshotResponse.md)
 - [SecretCreateRequest](docs/SecretCreateRequest.md)
 - [SecretResponse](docs/SecretResponse.md)
 - [SecretSearchRequest](docs/SecretSearchRequest.md)
 - [SecretUpdateRequest](docs/SecretUpdateRequest.md)
 - [SerpClusterAddQueryRequest](docs/SerpClusterAddQueryRequest.md)
 - [SerpClusterAddQueryRequests](docs/SerpClusterAddQueryRequests.md)
 - [SerpClusterBestGroupsRequest](docs/SerpClusterBestGroupsRequest.md)
 - [SerpClusterGroupIntersectionsRequest](docs/SerpClusterGroupIntersectionsRequest.md)
 - [SerpClusterGroupSearchRequest](docs/SerpClusterGroupSearchRequest.md)
 - [SerpClusterGroupSubClustersRequest](docs/SerpClusterGroupSubClustersRequest.md)
 - [SerpClusterKeywordIntersectionsRequest](docs/SerpClusterKeywordIntersectionsRequest.md)
 - [SerpClusterKeywordResponse](docs/SerpClusterKeywordResponse.md)
 - [SerpGroupIntersection](docs/SerpGroupIntersection.md)
 - [SerpKeyword](docs/SerpKeyword.md)
 - [SerpKeywordRelation](docs/SerpKeywordRelation.md)
 - [SerpQueryRequest](docs/SerpQueryRequest.md)
 - [SerpSearchEngineType](docs/SerpSearchEngineType.md)
 - [SerpSearchRequest](docs/SerpSearchRequest.md)
 - [SerpSearchRequests](docs/SerpSearchRequests.md)
 - [SerpSubclusterKeywordsResponse](docs/SerpSubclusterKeywordsResponse.md)
 - [SerpVolumeRequest](docs/SerpVolumeRequest.md)
 - [ShopRedactPayload](docs/ShopRedactPayload.md)
 - [SlackChannelResponse](docs/SlackChannelResponse.md)
 - [SlackWorkspaceResponse](docs/SlackWorkspaceResponse.md)
 - [SortDirection](docs/SortDirection.md)
 - [SubscriptionPlan](docs/SubscriptionPlan.md)
 - [TagCreateRequest](docs/TagCreateRequest.md)
 - [TagResponse](docs/TagResponse.md)
 - [TagSearchRequest](docs/TagSearchRequest.md)
 - [TagUpdateRequest](docs/TagUpdateRequest.md)
 - [TaskResponse](docs/TaskResponse.md)
 - [TaskStatus](docs/TaskStatus.md)
 - [TrackingClickIdNames](docs/TrackingClickIdNames.md)
 - [TrackingEventCreateRequest](docs/TrackingEventCreateRequest.md)
 - [TrackingEventCreateRequests](docs/TrackingEventCreateRequests.md)
 - [TrackingEventData](docs/TrackingEventData.md)
 - [TrackingEventResponse](docs/TrackingEventResponse.md)
 - [TrackingEventSearchRequest](docs/TrackingEventSearchRequest.md)
 - [TrackingEventsResponse](docs/TrackingEventsResponse.md)
 - [TrackingLinkCreateRequest](docs/TrackingLinkCreateRequest.md)
 - [TrackingLinkResponse](docs/TrackingLinkResponse.md)
 - [TrackingLinkSearchRequest](docs/TrackingLinkSearchRequest.md)
 - [TrackingLinksCreateRequest](docs/TrackingLinksCreateRequest.md)
 - [TrackingLinksResponse](docs/TrackingLinksResponse.md)
 - [TrackingSourceCreateRequest](docs/TrackingSourceCreateRequest.md)
 - [TrackingSourceResponse](docs/TrackingSourceResponse.md)
 - [TrackingSourceSearchRequest](docs/TrackingSourceSearchRequest.md)
 - [TrackingSourceTypes](docs/TrackingSourceTypes.md)
 - [TrackingSourcesResponse](docs/TrackingSourcesResponse.md)
 - [TransactionType](docs/TransactionType.md)
 - [TranscriptTaskRequest](docs/TranscriptTaskRequest.md)
 - [TriggerResponse](docs/TriggerResponse.md)
 - [TriggerType](docs/TriggerType.md)
 - [UrlScreenshotResponse](docs/UrlScreenshotResponse.md)
 - [UserDocumentStatus](docs/UserDocumentStatus.md)
 - [UserPlanResponse](docs/UserPlanResponse.md)
 - [UserResponse](docs/UserResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [VectorDocumentResponse](docs/VectorDocumentResponse.md)
 - [VectorDocumentType](docs/VectorDocumentType.md)
 - [VectorDocumentsTaskResponse](docs/VectorDocumentsTaskResponse.md)
 - [WordPressCategoryResponse](docs/WordPressCategoryResponse.md)
 - [WordPressSiteResponse](docs/WordPressSiteResponse.md)
 - [WordPressTagsResponse](docs/WordPressTagsResponse.md)
 - [WorkspaceCreateRequest](docs/WorkspaceCreateRequest.md)
 - [WorkspaceResponse](docs/WorkspaceResponse.md)
 - [WorkspaceRole](docs/WorkspaceRole.md)
 - [WorkspaceSSOCreateRequest](docs/WorkspaceSSOCreateRequest.md)
 - [WorkspaceSSODomainVerificationCreateRequest](docs/WorkspaceSSODomainVerificationCreateRequest.md)
 - [WorkspaceSSODomainVerificationResponse](docs/WorkspaceSSODomainVerificationResponse.md)
 - [WorkspaceSSOListResponse](docs/WorkspaceSSOListResponse.md)
 - [WorkspaceSSOResponse](docs/WorkspaceSSOResponse.md)
 - [WorkspaceSSOUpdateRequest](docs/WorkspaceSSOUpdateRequest.md)
 - [WorkspaceSearchRequest](docs/WorkspaceSearchRequest.md)
 - [WorkspaceUpdateRequest](docs/WorkspaceUpdateRequest.md)
 - [WorkspaceUserCreateRequest](docs/WorkspaceUserCreateRequest.md)
 - [WorkspaceUserResponse](docs/WorkspaceUserResponse.md)
 - [WorkspaceUserUpdateRequest](docs/WorkspaceUserUpdateRequest.md)
 - [WorkspaceUsersSearchRequest](docs/WorkspaceUsersSearchRequest.md)
 - [YoutubeContent](docs/YoutubeContent.md)
 - [YoutubeTranscriptRequest](docs/YoutubeTranscriptRequest.md)
 - [YoutubeTranscriptResponse](docs/YoutubeTranscriptResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKeyHeader"></a>
### APIKeyHeader

- **Type**: API key
- **API key parameter name**: Api-Key
- **Location**: HTTP header

<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author




